All of lore.kernel.org
 help / color / mirror / Atom feed
From: Maxime Ripard <maxime@cerno.tech>
To: Maxime Ripard <mripard@kernel.org>,
	Maarten Lankhorst <maarten.lankhorst@linux.intel.com>,
	 Daniel Vetter <daniel@ffwll.ch>,
	Thomas Zimmermann <tzimmermann@suse.de>,
	David Airlie <airlied@gmail.com>
Cc: David Gow <davidgow@google.com>,
	Dave Stevenson <dave.stevenson@raspberrypi.com>,
	Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
	Maíra Canal <mcanal@igalia.com>,
	Javier Martinez Canillas <javierm@redhat.com>,
	dri-devel@lists.freedesktop.org, linux-kernel@vger.kernel.org,
	linaro-mm-sig@lists.linaro.org,
	Brendan Higgins <brendan.higgins@linux.dev>,
	Maxime Ripard <maxime@cerno.tech>,
	linux-kselftest@vger.kernel.org, kunit-dev@googlegroups.com,
	Maíra Canal <mairacanal@riseup.net>,
	linux-media@vger.kernel.org
Subject: [PATCH v3 05/20] drm/tests: helpers: Rename the device init helper
Date: Thu, 01 Dec 2022 16:11:36 +0100	[thread overview]
Message-ID: <20221123-rpi-kunit-tests-v3-5-4615a663a84a@cerno.tech> (raw)
In-Reply-To: <20221123-rpi-kunit-tests-v3-0-4615a663a84a@cerno.tech>

The name doesn't really fit the conventions for the other helpers in
DRM/KMS, so let's rename it to make it obvious that we allocate a new
DRM device.

Reviewed-by: Maíra Canal <mcanal@igalia.com>
Signed-off-by: Maxime Ripard <maxime@cerno.tech>
---
 drivers/gpu/drm/tests/drm_client_modeset_test.c | 3 ++-
 drivers/gpu/drm/tests/drm_kunit_helpers.c       | 8 +++++---
 drivers/gpu/drm/tests/drm_modes_test.c          | 3 ++-
 drivers/gpu/drm/tests/drm_probe_helper_test.c   | 5 +++--
 include/drm/drm_kunit_helpers.h                 | 5 ++++-
 5 files changed, 16 insertions(+), 8 deletions(-)

diff --git a/drivers/gpu/drm/tests/drm_client_modeset_test.c b/drivers/gpu/drm/tests/drm_client_modeset_test.c
index ed2f62e92fea..6cdf08f582ce 100644
--- a/drivers/gpu/drm/tests/drm_client_modeset_test.c
+++ b/drivers/gpu/drm/tests/drm_client_modeset_test.c
@@ -59,7 +59,8 @@ static int drm_client_modeset_test_init(struct kunit *test)
 
 	test->priv = priv;
 
-	priv->drm = drm_kunit_device_init(test, DRIVER_MODESET, "drm-client-modeset-test");
+	priv->drm = drm_kunit_helper_alloc_drm_device(test, DRIVER_MODESET,
+						      "drm-client-modeset-test");
 	KUNIT_ASSERT_NOT_ERR_OR_NULL(test, priv->drm);
 
 	ret = drmm_connector_init(priv->drm, &priv->connector,
diff --git a/drivers/gpu/drm/tests/drm_modes_test.c b/drivers/gpu/drm/tests/drm_modes_test.c
index 3953e478c4d0..6723089dff9f 100644
--- a/drivers/gpu/drm/tests/drm_modes_test.c
+++ b/drivers/gpu/drm/tests/drm_modes_test.c
@@ -22,7 +22,8 @@ static int drm_test_modes_init(struct kunit *test)
 	priv = kunit_kzalloc(test, sizeof(*priv), GFP_KERNEL);
 	KUNIT_ASSERT_NOT_NULL(test, priv);
 
-	priv->drm = drm_kunit_device_init(test, DRIVER_MODESET, "drm-modes-test");
+	priv->drm = drm_kunit_helper_alloc_drm_device(test, DRIVER_MODESET,
+						      "drm-modes-test");
 	KUNIT_ASSERT_NOT_ERR_OR_NULL(test, priv->drm);
 
 	test->priv = priv;
diff --git a/drivers/gpu/drm/tests/drm_probe_helper_test.c b/drivers/gpu/drm/tests/drm_probe_helper_test.c
index 1f3941c150ae..85236ff4744f 100644
--- a/drivers/gpu/drm/tests/drm_probe_helper_test.c
+++ b/drivers/gpu/drm/tests/drm_probe_helper_test.c
@@ -39,8 +39,9 @@ static int drm_probe_helper_test_init(struct kunit *test)
 	KUNIT_ASSERT_NOT_NULL(test, priv);
 	test->priv = priv;
 
-	priv->drm = drm_kunit_device_init(test, DRIVER_MODESET | DRIVER_ATOMIC,
-					  "drm-probe-helper-test");
+	priv->drm = drm_kunit_helper_alloc_drm_device(test,
+						      DRIVER_MODESET | DRIVER_ATOMIC,
+						      "drm-probe-helper-test");
 	KUNIT_ASSERT_NOT_ERR_OR_NULL(test, priv->drm);
 
 	connector = &priv->connector;
diff --git a/include/drm/drm_kunit_helpers.h b/include/drm/drm_kunit_helpers.h
index 20ab6eec4c89..e9870c7911fe 100644
--- a/include/drm/drm_kunit_helpers.h
+++ b/include/drm/drm_kunit_helpers.h
@@ -6,6 +6,9 @@
 struct drm_device;
 struct kunit;
 
-struct drm_device *drm_kunit_device_init(struct kunit *test, u32 features, char *name);
+struct drm_device *
+drm_kunit_helper_alloc_drm_device(struct kunit *test,
+				  u32 features,
+				  char *name);
 
 #endif // DRM_KUNIT_HELPERS_H_

diff --git a/drivers/gpu/drm/tests/drm_kunit_helpers.c b/drivers/gpu/drm/tests/drm_kunit_helpers.c
index 4fe131141718..e718073ba6e9 100644
--- a/drivers/gpu/drm/tests/drm_kunit_helpers.c
+++ b/drivers/gpu/drm/tests/drm_kunit_helpers.c
@@ -36,7 +36,7 @@ static void dev_free(struct kunit_resource *res)
 }
 
 /**
  * drm_kunit_device_init - Allocates a mock DRM device for KUnit tests
  * @test: The test context object
  * @features: Mocked DRM device driver features
  * @name: Name of the struct &device to allocate
@@ -52,7 +52,9 @@ static void dev_free(struct kunit_resource *res)
  * Returns:
  * A pointer to the new drm_device, or an ERR_PTR() otherwise.
  */
-struct drm_device *drm_kunit_device_init(struct kunit *test, u32 features, char *name)
+struct drm_device *
+drm_kunit_helper_alloc_drm_device(struct kunit *test,
+				  u32 features, char *name)
 {
 	struct kunit_dev *kdev;
 	struct drm_device *drm;
@@ -82,7 +84,7 @@ struct drm_device *drm_kunit_device_init(struct kunit *test, u32 features, char
 
 	return drm;
 }
-EXPORT_SYMBOL_GPL(drm_kunit_device_init);
+EXPORT_SYMBOL_GPL(drm_kunit_helper_alloc_drm_device);
 
 MODULE_AUTHOR("Maxime Ripard <maxime@cerno.tech>");
 MODULE_LICENSE("GPL");
@@ -36,7 +36,7 @@ static void dev_free(struct kunit_resource *res)
 
 /**
- * drm_kunit_device_init - Allocates a mock DRM device for KUnit tests
+ * drm_kunit_helper_alloc_drm_device - Allocates a mock DRM device for KUnit tests
  * @test: The test context object
  * @features: Mocked DRM device driver features
-- 
b4 0.10.1

  parent reply	other threads:[~2022-12-01 15:15 UTC|newest]

Thread overview: 36+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-12-01 15:11 [PATCH v3 00/20] drm: Introduce Kunit Tests to VC4 Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 01/20] drm/tests: helpers: Move the helper header to include/drm Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 02/20] drm/tests: Introduce a config option for the KUnit helpers Maxime Ripard
2022-12-07 13:57   ` Maíra Canal
2022-12-07 13:57     ` Maíra Canal
2022-12-01 15:11 ` [PATCH v3 03/20] drm/tests: helpers: Document drm_kunit_device_init() Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 04/20] drm/tests: helpers: Switch to EXPORT_SYMBOL_GPL Maxime Ripard
2022-12-07 13:59   ` Maíra Canal
2022-12-07 13:59     ` Maíra Canal
2022-12-01 15:11 ` Maxime Ripard [this message]
2022-12-01 15:11 ` [PATCH v3 06/20] drm/tests: helpers: Remove the name parameter Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 07/20] drm/tests: helpers: Create the device in another function Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 08/20] drm/tests: helpers: Switch to a platform_device Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 09/20] drm/tests: helpers: Make sure the device is bound Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 10/20] drm/tests: helpers: Allow for a custom device struct to be allocated Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 11/20] drm/tests: helpers: Allow to pass a custom drm_driver Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 12/20] drm/tests: Add a test for DRM managed actions Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 13/20] drm/vc4: Move HVS state to main header Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 14/20] drm/vc4: crtc: Introduce a lower-level crtc init helper Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 15/20] drm/vc4: crtc: Make encoder lookup helper public Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 16/20] drm/vc4: hvs: Provide a function to initialize the HVS structure Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 17/20] drm/vc4: tests: Introduce a mocking infrastructure Maxime Ripard
2022-12-07 14:08   ` Maíra Canal
2022-12-07 14:08     ` Maíra Canal
2022-12-01 15:11 ` [PATCH v3 18/20] drm/vc4: tests: Fail the current test if we access a register Maxime Ripard
2022-12-07 14:26   ` Maíra Canal
2022-12-07 14:26     ` Maíra Canal
2022-12-07 16:11     ` Maxime Ripard
2022-12-07 16:11       ` Maxime Ripard
2022-12-01 15:11 ` [PATCH v3 19/20] drm/vc4: tests: Add unit test suite for the PV muxing Maxime Ripard
2022-12-07 14:24   ` Maíra Canal
2022-12-07 14:24     ` Maíra Canal
2022-12-01 15:11 ` [PATCH v3 20/20] Documentation: gpu: vc4: Add KUnit Tests Section Maxime Ripard
2022-12-07 13:55   ` Maíra Canal
2022-12-07 13:55     ` Maíra Canal
2022-12-08  8:58 ` [PATCH v3 00/20] drm: Introduce Kunit Tests to VC4 Maxime Ripard

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20221123-rpi-kunit-tests-v3-5-4615a663a84a@cerno.tech \
    --to=maxime@cerno.tech \
    --cc=airlied@gmail.com \
    --cc=brendan.higgins@linux.dev \
    --cc=daniel@ffwll.ch \
    --cc=dave.stevenson@raspberrypi.com \
    --cc=davidgow@google.com \
    --cc=dri-devel@lists.freedesktop.org \
    --cc=gregkh@linuxfoundation.org \
    --cc=javierm@redhat.com \
    --cc=kunit-dev@googlegroups.com \
    --cc=linaro-mm-sig@lists.linaro.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-kselftest@vger.kernel.org \
    --cc=linux-media@vger.kernel.org \
    --cc=maarten.lankhorst@linux.intel.com \
    --cc=mairacanal@riseup.net \
    --cc=mcanal@igalia.com \
    --cc=mripard@kernel.org \
    --cc=tzimmermann@suse.de \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.